﻿using System;
using Foundation;
using Syncfusion.SfChart.iOS;
using UIKit;

namespace Chart_GettingStarted
{
	public partial class ViewController : UIViewController
	{
		protected ViewController(IntPtr handle) : base(handle)
		{
			// Note: this .ctor should not contain any initialization logic.
		}

		public override void DidReceiveMemoryWarning()
		{
			base.DidReceiveMemoryWarning();
			// Release any cached data, images, etc that aren't in use.
		}

		SFChart chart;

		public override void ViewDidLoad()
		{
			base.ViewDidLoad();

			chart = new SFChart();
			chart.Frame = new CoreGraphics.CGRect(0, 0, View.Frame.Width , View.Frame.Height-100);

			UITextView label = new UITextView();
			label.Frame = new CoreGraphics.CGRect(0, View.Frame.Height-100, View.Frame.Width , 100);
			//Adding Primary Axis for the Chart.
			SFDateTimeAxis primaryAxis = new SFDateTimeAxis();
			chart.PrimaryAxis = primaryAxis;

			//Adding Secondary Axis for the Chart.
			SFNumericalAxis secondaryAxis = new SFNumericalAxis();
			chart.SecondaryAxis = secondaryAxis;

			//Defining the data source for the Chart.
			ChartDataModel dataModel = new ChartDataModel();
			chart.DataSource = dataModel as SFChartDataSource;
			CustomDelegate chartDelegate = new CustomDelegate(label);
			chart.Delegate = chartDelegate;
			chart.AddChartBehavior(new SFChartTrackballBehavior());
			//Adding our Chart as a sub view.
			this.View.AddSubview(chart);
			this.View.AddSubview(label);
		}

		public override void ViewDidLayoutSubviews()
		{
			//chart.Frame = this.View.Frame;
			base.ViewDidLayoutSubviews();
		}

	}

	public class CustomDelegate : SFChartDelegate
	{
		UITextView label;
		
		public CustomDelegate(UITextView _label) 
		{
			label = _label;
		}

		public override void DidTrackballLabelsGenerate(SFChart chart, NSArray pointsInfo)
		{
			for (nuint i = 0; i < (nuint)pointsInfo.Count; i++)
			{
				DateTime date = NSDateToDateTime((pointsInfo.GetItem<SFChartPointInfo>(i).Data.XValue) as NSDate);
				double yValue = Double.Parse((pointsInfo.GetItem<SFChartPointInfo>(i).Data.YValue).ToString());
				label.Text = "Date: " + date.ToString() + "\n" + "YValue: " + yValue.ToString();
			}
		}

		public DateTime NSDateToDateTime(NSDate date) 
		{
			DateTime reference = TimeZone.CurrentTimeZone.ToLocalTime(new DateTime(2001, 1, 1, 0, 0, 0));
			return reference.AddSeconds(date.SecondsSinceReferenceDate);
		}
	}

	public class ChartDataModel : SFChartDataSource
	{
		NSMutableArray DataPoints;
		NSCalendar calendar;

		public ChartDataModel()
		{
			DataPoints = new NSMutableArray();

			calendar = new NSCalendar(NSCalendarType.Gregorian);
			NSDateComponents comp = new NSDateComponents();
			comp.Day = 1;
			comp.Month = 1;
			comp.Year = 2015;
			comp.Hour = 0;
			comp.Minute = 0;
			comp.Second = 0;
			NSDate date = calendar.DateFromComponents(comp);
			SFChartDataPoint datas = new SFChartDataPoint(NSObject.FromObject(date), NSObject.FromObject(20));
			DataPoints.Add(datas);

			NSDateComponents dateComp= new NSDateComponents();
			dateComp.Month = 1;

			date = calendar.DateByAddingComponents(dateComp, date, NSCalendarOptions.None);
			datas = new SFChartDataPoint(NSObject.FromObject(date), NSObject.FromObject(25));
			DataPoints.Add(datas);

			date = calendar.DateByAddingComponents(dateComp, date, NSCalendarOptions.None);
			datas = new SFChartDataPoint(NSObject.FromObject(date), NSObject.FromObject(35));
			DataPoints.Add(datas);

			date = calendar.DateByAddingComponents(dateComp, date, NSCalendarOptions.None);
			datas = new SFChartDataPoint(NSObject.FromObject(date), NSObject.FromObject(15));
			DataPoints.Add(datas);

			date = calendar.DateByAddingComponents(dateComp, date, NSCalendarOptions.None);
			datas = new SFChartDataPoint(NSObject.FromObject(date), NSObject.FromObject(25));
			DataPoints.Add(datas);

		}


		public override nint NumberOfSeriesInChart(SFChart chart)
		{
			return 1;

		}


		public override SFSeries GetSeries(SFChart chart, nint index)
		{
			SFColumnSeries series = new SFColumnSeries();
			return series;

		}

		public override SFChartDataPoint GetDataPoint(SFChart chart, nint index, nint seriesIndex)
		{
			return DataPoints.GetItem<SFChartDataPoint>((nuint)index);
		}

		public override nint GetNumberOfDataPoints(SFChart chart, nint index)
		{
			return (int)DataPoints.Count;
		}

	}
}

